Initializing...

# GithubPages Installer

This installer will configure an action for publishing your vault directly to a github page.

This setup needs to be done once, after that, you can publish again by running
`obsidianhtml --publish githubpages` from the terminal.

## Set inputs

None selected
i
In default mode, ObsidianHtml will start compiling your website starting with this node, and following any links to any other note. This note has to be in the vault selected above.

## Set gitpages repo

Help me with setting up the gitpages repo
I have already set up a gitpages repo and cloned it locally
None selected.